@@ -1,14 +1,14 @@
 #!/usr/bin/env python
 
 import pytest
-
+import os
 
 import python_bioinformagicks as bim
 
 
 @pytest.fixture
 def sample_adata():
-    '''
+    """
     
     Loads an ad.AnnData object from disk to use
     in tests. This is data from multiple publications
@@ -16,7 +16,7 @@ def sample_adata():
     subsetting to 5% of the cells and the top
     2000 highly variable genes.
     
-    '''
+    """
 
     import anndata as ad
 
@@ -27,11 +27,6 @@ def test_scale_by_group(
     sample_adata,
     groupby = "celltype"
 ):
-    '''
-    
-    Testing bim.tl.scale_by_group.
-
-    '''
 
     import numpy as np
     
@@ -51,11 +46,6 @@ def test_subset_by_geosketching(
     frac_cells_to_keep = 0.2,
     n_cells_to_keep = 100,
 ):
-    '''
-
-    Testing bim.tl.subset_by_geosketching
-
-    '''
 
     import numpy as np
 
@@ -81,11 +71,6 @@ def test_subset_by_geosketching(
 def test_calc_jasmine_score(
     sample_adata,
 ):
-    '''
-
-    Testing bim.tl.calc_jasmine_score
-
-    '''
     
     import numpy as np
 
@@ -116,18 +101,49 @@ def test_calc_jasmine_score(
 def test_tf_idf_markers(
     sample_adata,
     n_genes = 10,
-    groupby = "celltype"
+    groupby = "celltype",
+    return_fig = True,
 ):
-    '''
 
-    Testing bim.tl.tf_idf_markers
+    #import matplotlib.pyplot as plt
 
-    '''
-    markers_dict = bim.tl.tf_idf_markers(
+    markers_dict, dpl = bim.tl.tf_idf_markers(
         sample_adata,
         n_genes = n_genes,
-        groupby = groupby
+        groupby = groupby,
+        return_fig = return_fig,
     )
-
+    
+    save_path = "./tests/data/plot_tf_idf_markers.png"
+    dpl.savefig(save_path)
+    #plt.close(dpl.gcf())
+    
     assert (len(markers_dict.keys()) == len(sample_adata.obs[groupby].unique()))
-    assert (len(markers_dict[list(markers_dict.keys())[0]]) == n_genes)
\ No newline at end of file
+    assert (len(markers_dict[list(markers_dict.keys())[0]]) == n_genes)
+    assert (os.path.getsize(save_path) > 100000)
+
+
+def test_call_scSNP(
+    sample_adata,
+    bam_file = "./tests/data/subsample.bam",
+    contig = "14",
+    position = 54962583,
+    alt = "C",
+    cb_tag = "CR"
+):
+    
+    barcodes = sample_adata.obs.index.tolist()
+
+    calls, stats = bim.tl.call_scSNP(
+        barcodes,
+        bam_file,
+        contig = "14",
+        position = 54962583,
+        alt = "C",
+        cb_tag = cb_tag,
+        return_stats = True
+    )
+    
+    assert (len(calls) == len(barcodes))
+    #assert (sum(calls) > 0)
+    print(stats)
\ No newline at end of file
