@@ -8,15 +8,13 @@ import python_bioinformagicks as bim
 
 @pytest.fixture
 def sample_adata():
-    '''
-    
+    """
     Loads an ad.AnnData object from disk to use
     in tests. This is data from multiple publications
     that has been integrated and annotated before 
     subsetting to 5% of the cells and the top
     2000 highly variable genes.
-    
-    '''
+    """
 
     import anndata as ad
 
@@ -26,14 +24,12 @@ def sample_adata():
 def test_in_ignore_list(
     sample_adata,
 ):
-    '''
-
+    """
     Testing bim.util.in_ignore_list
 
     A few ignorable genes were left in the test
     AnnData object; make sure they get detected.
-
-    '''
+    """
 
     import numpy as np
 
@@ -45,6 +41,7 @@ def test_in_ignore_list(
     assert ("mt-Rnr1" in ignored_genes)
     assert ("C330002G04Rik" in ignored_genes)
     assert ("Gm29538" in ignored_genes)
+    assert ("Actb" not in ignored_genes)
 
 
 def test_make_combined_categorical_column(
@@ -52,11 +49,14 @@ def test_make_combined_categorical_column(
     col_a = "age",
     col_b = "celltype"
 ):
-    '''
-
+    """
     Testing bim.util.make_combined_categorical_column
 
-    '''
+    If we combine the age column with the celltype column,
+    we expect age to be first in the order and celltype
+    to be second. E12 and ASM are ages and celltypes
+    in the sample_adata object. 
+    """
 
     df = sample_adata.obs
 
